@@ -2,7 +2,7 @@ from .alpha import decimal
 from .utils.Classes.RegEx import RegEx
 from .utils.assert_string import assert_string
 from .utils.includes import includes
-from .utils.math import grather_then_check, less_then_check
+from .utils.math import gather_then_check, less_then_check
 from .utils.merge import merge
 
 __default_options = {
@@ -22,15 +22,15 @@ def is_float(input: str, options=__default_options) -> bool:
     if includes(['+', '-', '.', ''], input):
         return False
 
-    float_pattern = RegEx("^(?:[-+])?(?:[0-9]+)?(?:\{}[0-9]*)?(?:[eE][\+\-]?(?:[0-9]+))?$".format(decimal[options["locale"]] if bool(options["locale"]) else '.'))
+    float_pattern = RegEx(r"^(?:[-+])?(?:[0-9]+)?(?:\{}[0-9]*)?(?:[eE][\+\-]?(?:[0-9]+))?$".format(decimal[options["locale"]] if bool(options["locale"]) else '.'))
 
     transformed_input = input.sub(',', '.').sub('٫', '.')
 
     is_valid = float_pattern.match(input)
 
-    min_valid = grather_then_check(transformed_input, options["min"])
+    min_valid = gather_then_check(transformed_input, options["min"])
     max_valid = less_then_check(transformed_input, options["max"])
-    gt_valid = grather_then_check(transformed_input, options["gt"])
+    gt_valid = gather_then_check(transformed_input, options["gt"])
     lt_valid = less_then_check(transformed_input, options["lt"])
 
     return is_valid and min_valid and max_valid and lt_valid and gt_valid
