@@ -6,6 +6,6 @@ def assert_string(input: str) -> String:
 
     if not is_string:
         invalid_type = type(input).__name__
-        raise Exception("Expected a string but received a {0}".format(invalid_type))
+        raise ValueError(f"Expected a string but received a {invalid_type}")
 
     return String(input)
